==> 0.0.8.tar.gz: android/src/main/java/com/admost/admost_flutter_plugin/AdmostFlutterPlugin.java <==
package com.admost.admost_flutter_plugin;

import android.app.Activity;

import admost.sdk.base.AdMost;
import admost.sdk.base.AdMostConfiguration;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterAdmostPlugin */
public class AdmostFlutterPlugin implements MethodCallHandler {
  /** Plugin registration. */
  private final Activity activity;

  private AdmostFlutterPlugin(Activity activity) {
      this.activity = activity;
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "admost_flutter");
    channel.setMethodCallHandler(new AdmostFlutterPlugin(registrar.activity()));

    final MethodChannel interstitialChannel = new MethodChannel(registrar.messenger(), "admost_flutter/interstitial");
    interstitialChannel.setMethodCallHandler(new AdmostIntersitital(registrar));

    final MethodChannel rewardChannel = new MethodChannel(registrar.messenger(), "admost_flutter/rewarded");
    rewardChannel.setMethodCallHandler(new AdmostRewarded(registrar));

    registrar.platformViewRegistry().registerViewFactory("admost_flutter/banner", new AdmostBannerFactory(registrar.messenger(), registrar.activity()));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("initialize")) {
        AdMostConfiguration.Builder configuration = new AdMostConfiguration.Builder(activity, (String) call.arguments);
        AdMost.getInstance().init(configuration.build());
    } else if (call.method.equals("startTestSuite")) {
        AdMost.getInstance().startTestSuite();
    }
  }
}

==> 1.0.2.tar.gz: android/src/main/java/com/admost/admost_flutter_plugin/AdmostFlutterPlugin.java <==
package com.admost.admost_flutter_plugin;

import android.app.Activity;

import admost.sdk.base.AdMost;
import admost.sdk.base.AdMostConfiguration;
import admost.sdk.base.AdMostLog;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterAdmostPlugin */
public class AdmostFlutterPlugin implements MethodCallHandler {
  /** Plugin registration. */
  private final Activity activity;

  private AdmostFlutterPlugin(Activity activity) {
      this.activity = activity;
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "admost_flutter");
    channel.setMethodCallHandler(new AdmostFlutterPlugin(registrar.activity()));

    final MethodChannel interstitialChannel = new MethodChannel(registrar.messenger(), "admost_flutter/interstitial");
    interstitialChannel.setMethodCallHandler(new AdmostIntersitital(registrar));

    final MethodChannel rewardChannel = new MethodChannel(registrar.messenger(), "admost_flutter/rewarded");
    rewardChannel.setMethodCallHandler(new AdmostRewarded(registrar));

    registrar.platformViewRegistry().registerViewFactory("admost_flutter/banner", new AdmostBannerFactory(registrar.messenger(), registrar.activity()));
  }
    String subjectToGDPR, subjectToCCPA, userConsent;
  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("initialize")) {
        String appId = call.argument("appId");
        AdMostConfiguration.Builder configuration = new AdMostConfiguration.Builder(activity,appId);
        if(call.hasArgument("subjectToGDPR")){
            subjectToGDPR = call.argument("subjectToGDPR");
            configuration.setSubjectToGDPR(subjectToGDPR.equals("1"));
        }
        if(call.hasArgument("subjectToCCPA")){
            subjectToCCPA = call.argument("subjectToCCPA");
            configuration.setSubjectToCCPA(subjectToCCPA.equals("1"));
        }
        if(call.hasArgument("userConsent")){
            userConsent =  call.argument("userConsent");
            configuration.setUserConsent(userConsent.equals("1"));
        }

        AdMost.getInstance().init(configuration.build());



    } else if (call.method.equals("startTestSuite")) {
            AdMost.getInstance().startTestSuite();
    }

  }
}
